#!/usr/bin/env python3

import env
from blinker import signal

def exec_code(code, input_cb):
    env.prepare_env(input_cb)
    try:
        exec(code)
    except Exception as e:
        exception = signal('plutoid::exception')
        exception.send('plutoid', exception=e)
    finally:
        env.revert_env()



import os
os.environ['MPLBACKEND'] = 'module://matplotlib_backend'

import matplotlib
import matplotlib.pyplot as plt
import numpy as np

import sys
import builtins

import stream

orig_env = {}
orig_env["stdout"] = sys.stdout
orig_env["stderr"] = sys.stderr
orig_env["input"] = builtins.input


def prepare_env(input_cb):
    sys.stdout = stream.OutStream('stdout')
    sys.stderr = stream.OutStream('stderr')
    builtins.input = input_cb
    
def revert_env():
    sys.stdout = orig_env["stdout"]
    sys.stderr = orig_env["stderr"]
    builtins.input = orig_env["input"]


#!/usr/bin/env python3

import executor
from blinker import signal

outs = []
def out(sender, content):
    outs.append(content)

errs = []
def err(sender, content):
    errs.append(content)

es = []
def except_cb(sender, exception):
    es.append(exception)

def input_cb(prompt):
    return prompt + 'xyz'

def matplotlib_cb(sender, mimetype, content):
    print(mimetype, content)

signal('plutoid::stdout').connect(out)
signal('plutoid::stderr').connect(err)
signal('plutoid::exception').connect(except_cb)
signal('plutoid::matplotlib').connect(matplotlib_cb)

code = '''
s = input('enter something: ')
print(s)
'''

executor.exec_code(code, input_cb)
print('out:')
print(''.join(outs))
print('err:')
print(''.join(errs))
print('exeception:')
print(es)

import matplotlib
import matplotlib.pyplot as plt
import numpy as np

t = np.arange(0.0, 2.0, 0.01)
s = 1 + np.sin(2*np.pi*t)
plt.plot(t, s)

plt.xlabel('time (s)')
plt.ylabel('voltage (mV)')
plt.title('About as simple as it gets, folks')
plt.grid(True)
plt.show()


#!/usr/bin/env python3

from distutils.core import setup

setup( name="plutoid",
    version = "0.1.0",
    description = "A light weight Python kernel",
    author = "Manas Garg",
    author_email = "manasgarg@gmail.com",
    license = "MIT",
    url = "https://github.com/manasgarg/plutoid",
    packages = ["plutoid"],
    long_description = "Plutoid is a light weight Python kernel that can be used for adding code execution capabilities to programming education applications.",
    python_requires='~=3.6',
)


#!/usr/bin/env python3

from blinker import signal

class OutStream(object):
    def __init__(self, stream_name):
        self.stream_name = stream_name
    
    def write(self, s):
        stream_data = signal('plutoid::%s' % self.stream_name)
        stream_data.send('plutoid', content=s)
    
    def writelines(self, lines):
        for line in lines:
            self.write(line)

    def flush( self):
        pass

    def truncate(self):
        pass